| Title: | Data dependencies for Naomi output generation |
|---|---|
| Description: | Makes data for Naomi output generation as an R package. |
| Authors: | Rachel Esra [aut, cre] |
| Maintainer: | Rachel Esra <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.8 |
| Built: | 2026-06-02 09:33:40 UTC |
| Source: | https://github.com/mrc-ide/naomi.resources |
This returns a list containing
The version of the package installed
The URL from the DESCRIPTION
A data frame with the files and their hashes for this country
get_resources_info(iso3)get_resources_info(iso3)
iso3 |
Country iso3 to get resources info for |
A list containing info about resources for this country
Get the path to the workbook template
get_shipp_workbook_path()get_shipp_workbook_path()
Path to the workbook template
Load dependencies for SHIPP PSE tool
load_shipp_exdata(data, iso3)load_shipp_exdata(data, iso3)
data |
Name of data dependency (see below for full description). |
iso3 |
Country iso3 |
Data input for SHIPP PSE tool.
Loaded SHIPP data.